<?php
/**
 * Set the content width based on the theme's design and stylesheet.
 */
 
//Content width 
if ( ! isset( $content_width ) ) {
	$content_width = 900;
}



//Js scripts
function pvs_theme_js_scripts() {
	if ( is_singular() ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'pvs_theme_js_scripts' );


//The theme supports:
add_theme_support( 'menus' );
add_theme_support( 'automatic-feed-links' );
add_theme_support( 'title-tag' );
add_theme_support( 'post-thumbnails' );
add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );
add_theme_support( 'post-formats', array(
		'aside'
	) );


//Disable top admin panel
add_filter('show_admin_bar', '__return_false');


//Widgets
function pvs_widgets(){
	register_sidebar( array(
		'name'          => __( 'Footer area left', 'pvs-neha' ),
		'id'            => 'sidebar-footer-area-left',
		'description'   => '',
		'before_widget' => '<div id="footer-widget-l-content">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4>',
		'after_title'   => '</h4>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer area right', 'pvs-neha' ),
		'id'            => 'sidebar-footer-area-right',
		'description'   => '',
		'before_widget' => '<div id="footer-widget-r-content">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4>',
		'after_title'   => '</h4>',
	) );
}
add_action( 'widgets_init', 'pvs_widgets' );
//End. Widgets

//Menu
register_nav_menus( array(
	'nehaleftmenu' => __( 'Neha Left Menu', 'pvs-neha' ),
	'nehabottommenu' => __( 'Neha Bottom Menu', 'pvs-neha' )
) );

function pvs_neha_menu() {
	get_template_part('menu');
}




//Theme header/footer for internal pages
$pvs_theme_header = '<div class="container second_page">' ;
$pvs_theme_footer = '</div>';




//Customize
function pvs_neha_customize($wp_customize) {

	//Logo
    $wp_customize->add_section(
        'pvs_neha_logo',
        array(
            'title' => 'Logo',
            'description' => '',
            'priority' => 1,
        )
    );
    
     $wp_customize->add_setting( 
    	'logo_upload', 
    	array(
			'default' => get_template_directory_uri() . '/assets/images/logo.png',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
    );
 
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'logo_upload',
			array(
				'label' => 'Logo Upload',
				'section' => 'pvs_neha_logo',
				'settings' => 'logo_upload'
			)
		)
	);
    
    $wp_customize->add_setting(
		'logo_text',
		array(
			'default' => 'Photostore',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	

	//End. Logo
	
	//Slideshow
	$wp_customize->add_section(
        'pvs_neha_slideshow',
        array(
            'title' => 'Homepage Slideshow',
            'description' => '',
            'priority' => 2,
        )
    );
    
    $wp_customize->add_setting(
		'hide_slideshow'
	);
	
	$wp_customize->add_control(
		'hide_slideshow',
		array(
			'label' => 'Hide Slideshow',
			'section' => 'pvs_neha_slideshow',
			'type' => 'checkbox',
		)
	);
    
    //Slide 1
    $wp_customize->add_setting( 
    	'slider1_upload', 
    	array(
			'default' => get_template_directory_uri() . '/assets/images/slide1.jpg',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
    );
 
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'slider1_upload',
			array(
				'label' => 'Slide 1 Upload',
				'section' => 'pvs_neha_slideshow',
				'settings' => 'slider1_upload'
			)
		)
	);
    
    $wp_customize->add_setting(
		'slider1_title',
		array(
			'default' => 'Sell',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider1_title',
		array(
			'label' => 'Slide 1 Title',
			'section' => 'pvs_neha_slideshow',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'slider1_title_red',
		array(
			'default' => 'Media',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider1_title_red',
		array(
			'label' => 'Slide 1 Title in Red',
			'section' => 'pvs_neha_slideshow',
			'type' => 'text',
		)
	);
	
	 $wp_customize->add_setting(
		'slider1_subtitle',
		array(
			'default' => 'Photo Stock',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider1_subtitle',
		array(
			'label' => 'Slide 1 Subtitle',
			'section' => 'pvs_neha_slideshow',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'slider1_description',
		array(
			'default' => 'The best way to sell your photos and prints online',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider1_description',
		array(
			'label' => 'Slide 1 Description',
			'section' => 'pvs_neha_slideshow',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'slider1_button_text',
		array(
			'default' => 'Browse catalog',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider1_button_text',
		array(
			'label' => 'Slide 1 Button text',
			'section' => 'pvs_neha_slideshow',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'slider1_button_link',
		array(
			'default' => site_url() . '/index.php?search=',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider1_button_link',
		array(
			'label' => 'Slide 1 Button link',
			'section' => 'pvs_neha_slideshow',
			'type' => 'text',
		)
	);
	//End. Slide 1
	
	//Slide 2
	$wp_customize->add_setting( 
    	'slider2_upload', 
    	array(
			'default' => get_template_directory_uri() . '/assets/images/slide2.jpg',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
    );
 
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'slider2_upload',
			array(
				'label' => 'Slide 2 Upload',
				'section' => 'pvs_neha_slideshow',
				'settings' => 'slider2_upload'
			)
		)
	);
    
    $wp_customize->add_setting(
		'slider2_title',
		array(
			'default' => 'Earn',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider2_title',
		array(
			'label' => 'Slide 2 Title',
			'section' => 'pvs_neha_slideshow',
			'type' => 'text',
		)
	);
	
    $wp_customize->add_setting(
		'slider2_title_red',
		array(
			'default' => 'commission',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider2_title_red',
		array(
			'label' => 'Slide 2 Title in red',
			'section' => 'pvs_neha_slideshow',
			'type' => 'text',
		)
	);	
	
    $wp_customize->add_setting(
		'slider2_subtitle',
		array(
			'default' => 'Signup as photographer',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider2_subtitle',
		array(
			'label' => 'Slide 2 Subtitle',
			'section' => 'pvs_neha_slideshow',
			'type' => 'text',
		)
	);	
	
	
	$wp_customize->add_setting(
		'slider2_description',
		array(
			'default' => 'Upload images, sell and earn commission',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider2_description',
		array(
			'label' => 'Slide 2 Description',
			'section' => 'pvs_neha_slideshow',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'slider2_button_text',
		array(
			'default' => 'Signup',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider2_button_text',
		array(
			'label' => 'Slide 2 Button text',
			'section' => 'pvs_neha_slideshow',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'slider2_button_link',
		array(
			'default' => site_url() . '/signup/',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider2_button_link',
		array(
			'label' => 'Slide 2 Button link',
			'section' => 'pvs_neha_slideshow',
			'type' => 'text',
		)
	);
	//End. Slide 2
	

	//End. Slideshow
	
	//Search
	$wp_customize->add_section(
        'pvs_neha_search',
        array(
            'title' => 'Search',
            'description' => '',
            'priority' => 3,
        )
    );
    
    $wp_customize->add_setting(
		'hide_search'
	);
	
	$wp_customize->add_control(
		'hide_search',
		array(
			'label' => 'Hide search bar',
			'section' => 'pvs_neha_search',
			'type' => 'checkbox',
		)
	);
	
	//End. Search
	
	
	//Banners
	$wp_customize->add_section(
        'pvs_neha_banners',
        array(
            'title' => 'Homepage Banners',
            'description' => '',
            'priority' => 3,
        )
    );
    
    $wp_customize->add_setting(
		'hide_banners'
	);
	
	$wp_customize->add_control(
		'hide_banners',
		array(
			'label' => 'Hide banners',
			'section' => 'pvs_neha_banners',
			'type' => 'checkbox',
		)
	);
    
    $wp_customize->add_setting( 
    	'banner1_upload', 
    	array(
			'default' => get_template_directory_uri() . '/assets/images/packages.jpg',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
    );
 
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'banner1_upload',
			array(
				'label' => 'Banner 1',
				'section' => 'pvs_neha_banners',
				'settings' => 'banner1_upload'
			)
		)
	);
	
	$wp_customize->add_setting(
		'banner1_url',
		array(
			'default' => site_url( ) . "/packages/",
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'banner1_url',
		array(
			'label' => 'Banner 1 URL',
			'section' => 'pvs_neha_banners',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'banner1_title',
		array(
			'default' => 'Media',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'banner1_title',
		array(
			'label' => 'Banner 1 Title Black',
			'section' => 'pvs_neha_banners',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'banner1_title_red',
		array(
			'default' => 'packages',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'banner1_title_red',
		array(
			'label' => 'Banner 1 Title Red',
			'section' => 'pvs_neha_banners',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'banner1_description',
		array(
			'default' => 'Buy 10 photos for',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'banner1_description',
		array(
			'label' => 'Banner 1 Title Black',
			'section' => 'pvs_neha_banners',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'banner1_description_red',
		array(
			'default' => '$5',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'banner1_description_red',
		array(
			'label' => 'Banner 1 Title Red',
			'section' => 'pvs_neha_banners',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting( 
    	'banner2_upload', 
    	array(
			'default' => get_template_directory_uri() . '/assets/images/collections.jpg',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
    );
 
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'banner2_upload',
			array(
				'label' => 'Banner 2',
				'section' => 'pvs_neha_banners',
				'settings' => 'banner2_upload'
			)
		)
	);
	
	$wp_customize->add_setting(
		'banner2_url',
		array(
			'default' => site_url( ) . "/media-collections/",
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'banner2_url',
		array(
			'label' => 'Banner 2 URL',
			'section' => 'pvs_neha_banners',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'banner2_subheader',
		array(
			'default' => 'Summer Sale',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'banner2_subheader',
		array(
			'label' => 'Banner 2 Subheader',
			'section' => 'pvs_neha_banners',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'banner2_title',
		array(
			'default' => 'Media',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'banner2_title',
		array(
			'label' => 'Banner 2 Title Black',
			'section' => 'pvs_neha_banners',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'banner2_title_red',
		array(
			'default' => 'Collections',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'banner2_title_red',
		array(
			'label' => 'Banner 2 Title Red',
			'section' => 'pvs_neha_banners',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'banner2_description',
		array(
			'default' => 'Photo\'s collections for',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'banner2_description',
		array(
			'label' => 'Banner 2 Title Black',
			'section' => 'pvs_neha_banners',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'banner2_description_red',
		array(
			'default' => '$50',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'banner2_description_red',
		array(
			'label' => 'Banner 2 Title Red',
			'section' => 'pvs_neha_banners',
			'type' => 'text',
		)
	);	
	
	
	$wp_customize->add_setting( 
    	'banner3_upload', 
    	array(
			'default' => get_template_directory_uri() . '/assets/images/prints.jpg',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
    );
 
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'banner3_upload',
			array(
				'label' => 'Banner 3',
				'section' => 'pvs_neha_banners',
				'settings' => 'banner3_upload'
			)
		)
	);
	
	
	$wp_customize->add_setting(
		'banner3_url',
		array(
			'default' => site_url( ) . "/index.php?search=&print_id=4137",
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'banner3_url',
		array(
			'label' => 'Banner 3 URL',
			'section' => 'pvs_neha_banners',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'banner3_title',
		array(
			'default' => 'Canvas',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'banner3_title',
		array(
			'label' => 'Banner 3 Title Black',
			'section' => 'pvs_neha_banners',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'banner3_title_red',
		array(
			'default' => 'Prints',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'banner3_title_red',
		array(
			'label' => 'Banner 3 Title Red',
			'section' => 'pvs_neha_banners',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'banner3_description',
		array(
			'default' => 'Select a photo and',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'banner3_description',
		array(
			'label' => 'Banner 3 Title Black',
			'section' => 'pvs_neha_banners',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'banner3_description_red',
		array(
			'default' => 'order print',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'banner3_description_red',
		array(
			'label' => 'Banner 3 Title Red',
			'section' => 'pvs_neha_banners',
			'type' => 'text',
		)
	);
	//End. Banners
	
	
	
	//Shock images
	$wp_customize->add_section(
        'pvs_neha_featured_images',
        array(
            'title' => 'Stock Photos',
            'description' => '',
            'priority' => 4,
        )
    );
    
    $wp_customize->add_setting(
		'hide_featured_images'
	);
	
	$wp_customize->add_control(
		'hide_featured_images',
		array(
			'label' => 'Hide stock images',
			'section' => 'pvs_neha_featured_images',
			'type' => 'checkbox',
		)
	);
	
	$wp_customize->add_setting(
		'featured_images_title',
		array(
			'default' => 'Stock Photos',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'featured_images_title',
		array(
			'label' => 'Title',
			'section' => 'pvs_neha_featured_images',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'featured_images_description',
		array(
			'default' => 'Lorem ipsum dolor sit amet, consectetur adipisicing elit. Voluptas nulla suscipits',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'featured_images_description',
		array(
			'label' => 'Description',
			'section' => 'pvs_neha_featured_images',
			'type' => 'text',
		)
	);
	
	
	//End. Stock images
	
	
	//Background
	$wp_customize->add_section(
        'pvs_neha_background',
        array(
            'title' => 'Background',
            'description' => '',
            'priority' => 5,
        )
    );
    
    $wp_customize->add_setting(
		'hide_background'
	);
	
	$wp_customize->add_control(
		'hide_background',
		array(
			'label' => 'Hide Background',
			'section' => 'pvs_neha_background',
			'type' => 'checkbox',
		)
	);
	
    $wp_customize->add_setting( 
    	'background_upload', 
    	array(
			'default' => get_template_directory_uri() . '/assets/images/background.jpg',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
    );
 
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'background_upload',
			array(
				'label' => 'Background',
				'section' => 'pvs_neha_background',
				'settings' => 'background_upload'
			)
		)
	);
	
	$wp_customize->add_setting(
		'background_url',
		array(
			'default' => site_url( ) . "/index.php?search=",
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'background_url',
		array(
			'label' => 'Background URL',
			'section' => 'pvs_neha_background',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'background_title',
		array(
			'default' => 'Millions of photos',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'background_title',
		array(
			'label' => 'Background Title',
			'section' => 'pvs_neha_background',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'background_button',
		array(
			'default' => 'Catalog',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'background_button',
		array(
			'label' => 'Background Button Title',
			'section' => 'pvs_neha_background',
			'type' => 'text',
		)
	);	
	
	//End. background
	
	
	//Latest images
	$wp_customize->add_section(
        'pvs_neha_latest_images',
        array(
            'title' => 'Homepage New images',
            'description' => '',
            'priority' => 6,
        )
    );
    
    $wp_customize->add_setting(
		'hide_latest_images'
	);
	
	$wp_customize->add_control(
		'hide_latest_images',
		array(
			'label' => 'New Images',
			'section' => 'pvs_neha_latest_images',
			'type' => 'checkbox',
		)
	);
	
	$wp_customize->add_setting(
		'latest_images_title',
		array(
			'default' => 'Latest images',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'latest_images_title',
		array(
			'label' => 'Title',
			'section' => 'pvs_neha_latest_images',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'latest_images_description',
		array(
			'default' => 'Hundreds of photos every day.',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'latest_images_description',
		array(
			'label' => 'Description',
			'section' => 'pvs_neha_latest_images',
			'type' => 'text',
		)
	);
	

	
	//End. latest images
	
	

	
	

	
	
	//Footer
    $wp_customize->add_section(
        'pvs_neha_footer',
        array(
            'title' => 'Footer',
            'description' => '',
            'priority' => 7,
        )
    );

	
	$wp_customize->add_setting(
		'footer_copyright_year',
		array(
			'default' => '2019',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'footer_copyright_year',
		array(
			'label' => 'Year',
			'section' => 'pvs_neha_footer',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'footer_copyright_text',
		array(
			'default' => 'Free Themes Cloud.',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'footer_copyright_text',
		array(
			'label' => 'Copyright',
			'section' => 'pvs_neha_footer',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'footer_copyright_link',
		array(
			'default' => 'https://freethemescloud.com/',
			'sanitize_callback' => 'pvs_neha_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'footer_copyright_link',
		array(
			'label' => 'Copyright Link',
			'section' => 'pvs_neha_footer',
			'type' => 'text',
		)
	);
	//End. Footer
}

add_action('customize_register', 'pvs_neha_customize' );

function pvs_neha_sanitize_text( $input ) {
    return wp_kses_post( force_balance_tags( $input ) );
}
//End. Customize
 
//PVS content
if ( function_exists ( 'pvs_content' ) ) {
	pvs_content();
	
	//Remove unnecessary js scripts and css
	add_action( 'wp_print_scripts', 'pvs_remove_scripts');
	add_action( 'wp_print_styles', 'pvs_remove_styles');

	function pvs_remove_scripts() {
		wp_dequeue_script( 'jquery' );
		wp_deregister_script( 'jquery' );
		
		wp_dequeue_script( 'pvs_jquery' );
		wp_deregister_script( 'pvs_jquery' );
		
		wp_dequeue_script( 'pvs_jqueryui' );
		wp_deregister_script( 'pvs_jqueryui' );
		
		wp_dequeue_script( 'bootstrap' );
		wp_deregister_script( 'bootstrap' );
		
		wp_dequeue_script( 'pvs_jshttprequest' );
		wp_deregister_script( 'pvs_jshttprequest' );
		
		wp_dequeue_script( 'pvs_custom_js' );
		wp_deregister_script( 'pvs_custom_js' );
	}
		
	function pvs_remove_styles() {
		wp_dequeue_style( 'pvs_css' );
		wp_deregister_style( 'pvs_css' );
		
		wp_dequeue_style( 'bootstrap_style' );
		wp_deregister_style( 'bootstrap_style' );
	}

	//Menu neha
	function pvs_build_menu_categories_neha($t_id) {
		global $db;
		global $dr;
		$dp = new TMySQLQuery;
		$dp->connection = $db;
		global $itg;
		global $nlimit;
		
		$nn  = 0;
		
		$sql = "select id, id_parent, title, priority, published, url from " . PVS_DB_PREFIX . "category where id_parent=" . $t_id . " and published=1 and activation_date < " . pvs_get_time() . " and (expiration_date > " . pvs_get_time() . " or expiration_date = 0) order by priority, title";
		$dp->open($sql);
		if (!$dp->eof) {
			while (!$dp->eof) {
				$title = pvs_category_url($dp->row["id"], $dp->row["url"]);
				
				$zp  = false;
				
				$sql = "select id, id_parent, title, priority, published, url from " . PVS_DB_PREFIX . "category where id_parent=" . $dp->row["id"] . " and published=1 and activation_date < " . pvs_get_time() . " and (expiration_date > " . pvs_get_time() . " or expiration_date = 0) order by priority, title";
				$dr->open($sql);
				if (!$dr->eof) {
				$zp = true;
				}
				
				if ($nlimit < 10000) {
					$translate_results = pvs_translate_category($dp->row["id"], $dp->row["title"], "", "");
					
					$ttl = addslashes($translate_results["title"]);
					
					if ($nn == 0) {
						$itg .= "<ul  class='sub-menu'>\n";
					}
					
					$class_dropdown  = "";
					
					if ($zp) {
						$class_dropdown = ' class="menu-item menu-item-has-children"';
					}
					
					$itg .= "<li " . $class_dropdown . "><a href=\"" . pvs_category_url($dp->row["id"], $dp->row["url"]) . "\" title=\"" . $ttl . "\">" . $ttl . "</a>\n";
					
					if (!$zp) {
						$itg .= "</li>";
					}
					pvs_build_menu_categories_neha($dp->row["id"]);
					if ($zp) {
						$itg .= "</li>";
					}
				}
				$nlimit++;
				$nn++;
				$dp->movenext();
			}
			$itg .= "</ul>\n";
		}
	}
	
	$itg="";
	$nlimit=0;
	pvs_build_menu_categories_neha(0);
	$pvs_theme_content[ 'box_categories' ] = $itg;
}


?>